// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#ifndef MONOPDCLIENT_H
#define MONOPDCLIENT_H

#include <QtGui/QWidget>
#include <QTcpSocket>
#include <QHttp>
#include <QDomDocument>
#include <QDomElement>
#include "monopdgame.h"
#include "monopdtemplate.h"
#include "monopdcard.h"

namespace Ui {
	class MonopdClient;
}

class MonopdClient : public QWidget {
	Q_OBJECT

	public:
		MonopdClient(QTcpSocket* sok, QWidget *parent = 0);
		~MonopdClient();

		Player* getPlayer(int pid, bool create=true);
		bool hasPlayer(int pid);
		MonopdTemplate* getTemplate(QString t);
		MonopdTemplate* getTemplateFromList(int n);
		MonopdGame* getGame(int gid, QString type="", bool create=false);
		MonopdGame* getGameFromList(int n);
		int getNumTemplates();
		int getNumGames();

		int getCurGameId();
		int getClientPlayerId();
		QString getClientCookie();

		void deletePlayer(Player* p);
		void deleteGame(MonopdGame* p);

		void setCurGameId(int id);
		void setClientPlayerId(int id);
		void setClientCookie(QString c);

		void leaveGame();

	protected:
		void changeEvent(QEvent *e);

	private:
		Ui::MonopdClient *m_ui;

		QTcpSocket* soket;
		QString cache;
		QList<Player*> players;
		QList<MonopdTemplate*> templates;
		QList<MonopdGame*> games;
		QList<QString> ips;

		//For getting Serverlist
		QHttp* httpSok;

		int curGameId;
		int clientPlayerId;
		QString clientCookie;

		void parseDoc(QDomDocument d);
		void parseMsg(QDomElement m);
		void parseDisplay(QDomElement d);
		void parseGamelistUpdate(QDomElement g, QString type);
		void parsePlayer(QDomElement f);
		void parseField(QDomElement f);
		void parseCard(QDomElement c);
		void parseTrade(QDomElement t);
		void parseAuction(QDomElement a);
		void parseGame(QDomElement g);
		void parseConfig(QDomElement c);
		void parseConfigOption(QDomElement o);
		void showData(QString data);

	private slots:
		void readData();
		void readServerList();
		void showError();

		void setServer(int r);
		void connectToServer();

	public slots:
		void connectToHost(QString host, int port);
		void send(QString msg);
		void disconnectFromHost();
		void updateServerList();

	signals:
		void fieldUpdate();
		void playerAdded(Player* p);
		void chatMessage(int playerid, QString msg);
		void serverMessage(QString type, QString msg);
		void playerUpdated();
		void playerPosChanged();

		void newGameList();
		void curGameChanged();
		void gameMasterChanged(int gid, int newMaster);
		void statusChanged(QString status);
		void gotField(int fid);
		void gotText(QString txt);
		void gotButton(QString txt, QString cmd);
		void clearedText();
		void clearedButtons();
		void cardUpdated(MonopdCard* c);

		void configUpdate(QString cmd, QString text, QString type, QString value);

		void auctionStarted();
		void auctionIdUpdate(int aid);
		void auctionFieldUpdate(int fid);
		void auctionBidUpdate(int pid, int bid);
		void auctionStatusUpdate(int status);

		void tradeUpdate(QString type, int tradeId, int actor, int rev);
		void tradePlayerUpdate(int tradeId, int playerid, bool accept);
		void tradeEstateUpdate(int tradeId, int estateId, int targetPlayerId);
		void tradeCardUpdate(int tradeId, int cardId, int targetPlayerId);
		void tradeMoneyUpdate(int tradeId, int fromPlayerId, int money, int targetPlayerId);

		void connected();
};

#endif // MONOPDCLIENT_H
